const AbstractController        = require("./AbstractController.js");
const LernstickConnectorService = require("../services/LernstickConnector/LernstickConnectorService.js")

/**
 * Manages documents requests
 *  @extends AbstractController
 */
class DocumentsController extends AbstractController {

    /**
     * Create a DocumentsController
     */
    constructor() {
        super();

        this.lernstickservice = LernstickConnectorService.getInstance();

        this.list       = this.list.bind(this);
        this.download   = this.download.bind(this);

    }


    /**
     * @openapi
     * /documents:
     *   get:
     *     tags:
     *      - DocumentsController
     *     description: List all examination documents
     *     responses:
     *       '200':
     *          description: Document list
     *       '500':
     *          $ref: '#/components/responses/ServerError'
     */
    async list(req, res) {
        try {
            const documents = this.lernstickservice.getExaminationDocuments();
            res.status(200);
            res.send({documents: documents});
        }catch (err){
            this._log().error(err);
            res.sendStatus(500);
        }
    }

    /**
     * @openapi
     * /documents/{id}:
     *   get:
     *     tags:
     *      - DocumentsController
     *     parameters:
     *      - $ref: '#/components/parameters/Identifier'
     *     description: Download document
     *     responses:
     *       '200':
     *          description: Document as file
     *       '500':
     *          $ref: '#/components/responses/ServerError'
     */
    async download(req, res) {
        try {
            if (typeof req.params["id"] === "undefined"
                || (typeof req.params["id"] !== "string" && !(req.params["id"] instanceof String))
                || !(/\w{8}-\w{4}-\w{4}-\w{4}-\w{12}/.test(req.params["id"]))){
                res.sendStatus(412);
                return;
            }
            await this.lernstickservice.downloadExaminationDocument(req.params["id"], res);
        }catch (err){
            this._log().error(err);
            res.sendStatus(500);
        }
    }

}

module.exports = DocumentsController;
