const AbstractController        = require("./AbstractController.js");
const LernstickConnectorService = require("../services/LernstickConnector/LernstickConnectorService.js")

/**
 * Manages hardware requests
 *  @extends AbstractController
 */
class HardwareController extends AbstractController {

    /**
     * Create a HardwareController
     */
    constructor() {
        super();

        this.lernstickservice = LernstickConnectorService.getInstance();

        this.getStatus = this.getStatus.bind(this);
    }


    /**
     * @openapi
     * /hardware/status:
     *   get:
     *     tags:
     *      - HardwareController
     *     description: Get hardware status
     *     responses:
     *       '200':
     *          description: Hashed url
     *       '500':
     *          $ref: '#/components/responses/ServerError'
     */
    async getStatus(req, res) {
        try {
            const hardwareStatus = this.lernstickservice.getHardwareInfo();
            res.status(200);
            res.send({hardwareStatus: hardwareStatus});
        }catch (err){
            this._log().error(err);
            res.sendStatus(500);
        }
    }
}

module.exports = HardwareController;
