const AbstractController        = require("./AbstractController.js");
const LernstickConnectorService = require("../services/LernstickConnector/LernstickConnectorService.js")

/**
 * Manages examination requests
 *  @extends AbstractController
 */
class LMSController extends AbstractController {

    /**
     * Create a LMSController
     */
    constructor() {
        super();

        this.lernstickservice = LernstickConnectorService.getInstance();

        this.hashMoodleURL = this.hashMoodleURL.bind(this);
    }


    /**
     * @openapi
     * /lms/moodle/hashurl:
     *   post:
     *     tags:
     *      - LMSController
     *     description: Hash a url with LMS examination key
     *     requestBody:
     *       required: true
     *       content:
     *         application/json:
     *           schema:
     *             type: object
     *             properties:
     *               url:
     *                  type: string
     *                  description: Url to hash
     *     responses:
     *       '200':
     *          description: Hashed url
     *       '412':
     *          $ref: '#/components/responses/PreconditionFailed'
     *       '500':
     *          $ref: '#/components/responses/ServerError'
     */
    async hashMoodleURL(req, res) {
        try {
            if (typeof req.body.url === "undefined"){
                res.sendStatus(412);
                return;
            }
            const hashedUrl = this.lernstickservice.hashURL(req.body.url);
            res.status(200);
            res.send({hashedUrl: hashedUrl});
        }catch (err){
            this._log().error(err);
            res.sendStatus(500);
        }
    }
}

module.exports = LMSController;
