const LogHelper = require("../helpers/LogHelper.js");

/**
 * Abstract service
 * @abstract
 */
class Service {

    /**
     * Initializes the singleton
     * @static
     */
    static initialize() {
        console.log("Have to be implemented");
    }

    /**
     * Initializes a service instance
     * @static
     * @returns {Service} Instance
     */
    static getInstance() {
        console.log("Have to be implemented");
    }

    /**
     * Singleton: Creates a Service instance
     * @returns {Service} Instance
     */
    constructor() {
        this._log   = this._log.bind(this);
        this._audit = this._audit.bind(this);
    }

    /**
     * Get logger
     * @return {Logger} Logger instance
     */
    _log(){ return LogHelper.getInstance().getLogger(); }

    /**
     * Get audit logger
     * @param {Integer} role - User roles
     * @param {String} id - User / device identifier
     * @param {String} severity - Log severity
     * @param {String} msg - Log message
     * @private
     */
    _audit(role, id, severity, msg){
        LogHelper.getInstance().audit(role, id, severity, msg);
    }
}

module.exports = Service;
