#!/bin/bash
# Name        : campla-lernstick-hwinfo.sh
# Description : Reads hardware information and export it to JSON file
# Author      : Simon Kaspar
# Version     : 0.1
# ---------------------------------------------------------------------------------------

TARGET_FILE="/tmp/campla-lernstick-hwinfo.json"

hardware_statistics="null"

gather_hardware_statistics(){
	local hasTPM="false"
	local tpmVersion="none"
	local resolution="none"
	local product="none"
	local os="none"
	local serialNumber=""

  # Import root CA into firefox
  if [ -d "/home/user/.mozilla/firefox" ];then
    if ! [ -e "/home/user/.mozilla/firefox/pki.ready" ];then
      /usr/bin/certutil -A -d /home/user/.mozilla/firefox/default-profile -i /etc/lernstick-pki/lernstick-ca.cert.pem -n "Lernstick CA" -t "C,,"
      touch "/home/user/.mozilla/firefox/pki.ready"
    fi
  fi

	if [ -c /dev/tpm0 ];then
		hasTPM="true"
		tpmVersion="1.2"
		if [ -c /dev/tpmrm0 ];then
			tpmVersion="2.0"
		fi
	fi

	if [ -e "/etc/build_info.txt" ];then
		os=$(sed ':a;N;$!ba;s/\n//g' /etc/build_info.txt)
	fi


	product="$(lshw -quiet -c "system" \
				| grep "product" \
				| head -n1 \
				| cut -d':' -f2 \
				| sed -e 's/^ *//g' \
				| sed -e 's/ *$//g' \
				| tr -d "\n")"

	hardware_statistics="{\"os\":\"${os}\", \"usb\": { \"serial\": \"${serialNumber}\" }, \"display\":{\"resolution\":\"==resolution==\"},\"system\":{\"product\":\"${product}\"},\"tpm\":{\"enabled\":${hasTPM},\"version\":\"${tpmVersion}\"}}"
}

function update_data(){
    # Get wifi connection info
    WIFI_CONNECTED="false"
    QUALITY="0.0"
    SSID=$(iwgetid -r)
    if ! [ -z "$SSID" ];then
        WIFI_CONNECTED="true"
        interface=$(iwgetid | cut -d' ' -f1)
        qualityParts=$(iwconfig "${interface}" | grep -oE "Link Quality=[0-9]*\/[0-9]*" | cut -d'=' -f2)
        QUALITY=$(echo "scale=4;${qualityParts}*100" | bc -l)
    fi

    # Get battery levels of notebook
    ct=0
    LEVELS="["
    while read bat; do
        level=$(upower -i "$bat" | grep "percentage" | grep -oE "[0-9]*")
        if [ $ct -eq 0 ];then
            LEVELS="${LEVELS}${level}"
        else
            LEVELS="${LEVELS},${level}"
        fi
        ct=$(( $ct + 1 ))
    done < <(upower -e | grep "BAT")
    LEVELS="${LEVELS}]"

    # Get resolution of notebook display
    if [ -e "/tmp/campla-lernstick-uiinfo.json" ];then
      resolution=$(cat "/tmp/campla-lernstick-uiinfo.json" | jq ".resolution" | sed -E 's/(^"|"$)//g')
      hardware_statistics_updated=$(echo "${hardware_statistics}" | sed "s/==resolution==/${resolution}/g")
    else
      hardware_statistics_updated=$(echo "${hardware_statistics}" | sed "s/==resolution==/none/g")
    fi
    echo -n "{\"wifi\": { \"connected\": ${WIFI_CONNECTED}, \"ssid\": \"${SSID}\", \"quality\": ${QUALITY} }, \"batteries\": ${LEVELS}, \"usb\": { \"serial\": \"${serialNumber}\" }, \"hardware\": ${hardware_statistics_updated} }" > "${TARGET_FILE}.tmp"
    mv "${TARGET_FILE}.tmp" "${TARGET_FILE}"
}

# Get serial number of usb stick
serialNumber=""
lsblk -OJ > "/tmp/diskinfo.json"
length=$(cat "/tmp/diskinfo.json" | jq ".blockdevices | length")
i=0
while [ $i -lt $length ]; do
  found=$(cat "/tmp/diskinfo.json" | jq ".blockdevices[${i}].label" | grep "lernstick")
  if ! [ -z "$found" ];then
    serialNumber=$(cat "/tmp/diskinfo.json" | jq ".blockdevices[${i}].serial" | sed 's/"//g')
    i=$length
  fi
  i=$(( $i + 1))
done

# Get hardware statistics
gather_hardware_statistics

while true; do
    update_data
    sleep 1
done
