#!/bin/bash
# Name        : campla-lernstick-uiinfo.sh
# Description : Reads information about the current ui session and export it to JSON file
# Author      : Ronny Standtke, Simon Kaspar
# Version     : 0.1
# ---------------------------------------------------------------------------------------

TARGET_FILE="/tmp/campla-lernstick-uiinfo.json"

gather_display_statistics(){
        local rdpScale=100
        local primaryDisplay=""
        local monitorWidth=0
        local screenWidth=0
        local dpi=0
        local scale=0
        local resolution=""

        resolution=$(xrandr 2>/dev/null \
          | grep ' connected' \
          | grep -oE "[0-9]+x[0-9]+" \
          | tr -d "\n")

        # try calculating good RDP_SCALE
        rdpScale=100

        # determine scaling
        primaryDisplay=$(xrandr | grep -w "connected primary")
        #printf "primary display:\\n%s\\n" "$primaryDisplay"
        if [ -n "$primaryDisplay" ]
        then
                monitorWidth=$(echo "$primaryDisplay" | sed 's/.* \(.*\)mm x .*mm/\1/g')
                #echo "monitor width: $monitorWidth mm"
                if [ "$monitorWidth" -ne 0 ]
                then
                        screenWidth=$(echo "$primaryDisplay" | sed 's/.* primary \(.*\)x.*+.*/\1/g')
                        #echo "screen width: $screenWidth pixels"
                        dpi=$((screenWidth*254/monitorWidth/10))
                        #echo "dpi: $dpi"
                        scale=$(echo "scale=2; ${dpi}/96" | bc)
                        #echo "scaling factor ($dpi/96): $scale"
                        if [ "$(echo "($scale > 1.4) && ($scale <= 1.8)" | bc -l)" -eq 1 ]
                        then
                                rdpScale=140
                        elif [ "$(echo "$scale > 1.8" | bc -l)" -eq 1 ]
                        then
                                rdpScale=180
                        fi
                fi
        fi
        echo -n "{\"rdp_scale\": ${rdpScale}, \"resolution\": \"${resolution}\" }" > "${TARGET_FILE}.tmp"
        mv "${TARGET_FILE}.tmp" "${TARGET_FILE}"
}

# Get ui statistics
gather_display_statistics

while true; do
    gather_display_statistics
    sleep 1
done

